PROVIDERS = {
    "Comic Action": {
        "base_url": "https://comic-action.com/episode/",
        "referer": "https://comic-action.com"
    },
    "Comic Days": {
        "base_url": "https://comic-days.com/episode/",
        "referer": "https://comic-days.com"
    },
    "Comic Gardo": {
        "base_url": "https://comic-gardo.com/episode/",
        "referer": "https://comic-gardo.com"
    },
    "Comic Zenon": {
        "base_url": "https://comic-zenon.com/episode/",
        "referer": "https://comic-zenon.com"
    },
    "Flat Hero's": {
        "base_url": "https://viewer.heros-web.com/episode/",
        "referer": "https://viewer.heros-web.com"
    },
    "Magcomi": {
        "base_url": "https://magcomi.com/episode/",
        "referer": "https://magcomi.com"
    },
    "Shonen Jump+": {
        "base_url": "https://shonenjumpplus.com/episode/",
        "referer": "https://shonenjumpplus.com"
    },
    "Sunday Webry": {
        "base_url": "https://www.sunday-webry.com/episode/",
        "referer": "https://www.sunday-webry.com"
    },
    "Tonarinoyj": {
        "base_url": "https://tonarinoyj.jp/episode/",
        "referer": "https://tonarinoyj.jp"
    }
}